/************************************************************************************
*                                                                                   *
*   File Name   : timer_irq.c                                                       *
*   Contents    : Timer interrupt related functions of Sanduhr                      *
*   Version     : 1.9                                                               *
*************************************************************************************/ 
#include "globals.h"

/************************************************************************************
Name:        TIMERX_init
Parameters:  None
Returns:     None
Description: Initial setting of Timer X registers
************************************************************************************/
void f_vd_TIMERX_init(void)
{
    txck0 = 1;                              /* Timer X count source = f8 */
    txck1 = 0;

    /* Setting the main cycle timer                   */
    /* 20 MHz * 1/8 * 1/50 * 1/10 => 250us  */
    prex = 50-1;                            /* Setting Prescaler X register */
    tx   = 10-1;                            /* Setting timer X register */

	
    txmr = 0x00;                            /* Timer X : timer mode */

    txs  = 1;                               /* Timer X count start flag = start */
}
/************************************************************************************
Name:        TIMERY_init
Parameters:  None
Returns:     None
Description: Initial setting of Timer Y registers
************************************************************************************/
void f_vd_TIMERY_init(void)
{
    tyck0 = 1;                              /* Timer Y count source = f8 */
    tyck1 = 0;

    /* Setting the main cycle timer                   */
    /* 20 MHz * 1/8 * 1/20 * 1/125 => 100 Hz = 1ms  */
    prey   = 20-1;                          /* Setting Prescaler Y register */
    tysc   = 0;                             /* Setting timer Y secondary register */
    typr   = 125-1;                         /* Setting timer Y register */

    tymod0 = 0;                             /* Timer Y : timer mode */
    tywc   = 0;                             /* Write to timer and reload register simultaneously */

    tyic = 5;                               /* Interrupt priority level = 5 */

    ir_tyic = 0;                            /* Interrupt request flag clear */
    tys  = 1;                               /* Timer Y count start flag = start */
}
/************************************************************************************
Name:        TIMERZ_init
Parameters:  None
Returns:     None
Description: Initial setting of Timer Y registers
************************************************************************************/
void f_vd_TIMERZ_init(void)
{
    tzs   = 0;                              /* Timer Z = stopped */
    tzck0 = 0;                              /* Timer Y underflow @1ms = count source */
    tzck1 = 1;

    prez   = 4-1;                           /* Setting Prescaler Z register */
    tzsc   = 200-1;                         /* Setting timer Z secondary register */
    tzpr   = 50-1;                          /* Setting timer Z primary register */

    tzmod0 = 1;                             
    tzmod1 = 0;                             /* Timer Z : Programmable waveform generation mode */
    tzwc   = 1;                             /* Write to timer and reload register simultaneously ? */

    tzocnt = 0;                             /* TZ-Output triggered from timer not GPIO */
    tzopl  = 0;                             /* TZ-Output H for primary, L for secondary, L for timer stop */
    inostg = 0;                             /* no interrupt trigger */    
    inoseg = 0;                             /* interrupt polarity */

}

/************************************************************************************
Name:        interrupt Timer Y
Parameters:  None
Returns:     None
Description: Timer Y
************************************************************************************/
#pragma interrupt timer_1ms_irq
void timer_1ms_irq(void)
{
unsigned long ul_inc_page_period = 0;
	//disable all IRQ's
	UL_TIRQ_count1ms++;                           /* 1 msecond counter increment */

	//read encoder every 1ms
	if (UI_STATE == D_adjustTimeState)
	{
	   f_vd_ENCODER_READ();
	}

        if (UI_STATE == D_runningState)
        {
	   //
	   ul_inc_page_period = UC_MINS_TO_RUN * 1000; //mins * 60s * 1000 ms / 60 pages
	   //update page depending on time to wait
	   if ( (UL_TIRQ_count1ms%ul_inc_page_period) == 0 )
	   {
              if (UC_CURRENT_POSITION == D_POS_UPRIGHT)
              {
                 if (UC_CURR_PAGE < 60)
                 {
                    UC_CURR_PAGE++;
                 } //end of if (UC_CURR_PAGE < 60)
              } //end of if (UC_CURRENT_POSITION == D_POS_UPRIGHT)
              else if (UC_CURRENT_POSITION == D_POS_HEADFIRST)
              {
                 if (UC_CURR_PAGE > 0)
                 {
                    UC_CURR_PAGE--;
                 }
              } //end of else if (UC_CURRENT_POSITION == D_POS_HEADFIRST)
           } //end of ( (UL_TIRQ_count1ms%ul_inc_page_period) == 0 )
	} //end of if (UI_STATE == D_runningState)

	//toggle LED all 1000ms
	if ( (UL_TIRQ_count1ms%1000) == 0 )           /* 1 second have passed ? */
    	{
        	ActLED_port = ~ActLED_port;
                #ifdef UART1_DEBUGGING
		    f_vd_sendValues();                    /* send XDIR, YDIR, ZDIR, POS values on UART1 for debugging purposes */
                #endif
	}
	//trigger ADC's all 100ms
	if ( (UL_TIRQ_count1ms%100) == 0 )           /* 0.1 second have passed ? */
    	{
        	f_vd_AcquireVoltages();
	}
	//enable all IRQ's
}
