/************************************************************************************
*                                                                                   *
*   File Name   : uart_functions.c                                                  *
*   Contents    : UART-related functions for the Sanduhr                            *
*   Version     : 1.3                                                               *
*************************************************************************************/ 
#include "globals.h"


#ifdef UART1_DEBUGGING
/************************************************************************************
Name:        sendTxd1
Parameters:  unsigned char data - byte to be send via UART1
Returns:     None
Description: Initial setting of UART1 registers
************************************************************************************/
void f_vd_sendTxd1(unsigned char data)
{
	while (ti_u1c1 == 0);
	u1tbl = data;
	te_u1c1 = 1;
}

/************************************************************************************
Name:        UART1_init
Parameters:  None
Returns:     None
Description: Initial setting of UART1 registers
************************************************************************************/
void f_vd_UART1_init(void)
{
        pd0_0 = 1;                              /* P0.0 = TxD11 Output */
        pd3_7 = 0;                              /* P3.7 = RxD1 Input */
	u1mr = 0x05; /* 8 bits to transmit */
	u1c0 = 0x00;
	u0rrm = 0;
	u1brg = 130-1;
	rxd1en = 0;
	txd1sel = 1;
	te_u1c1 = 1;
}

/************************************************************************************
Name:        sendValues
Parameters:  None
Returns:     None
Description: send values on UART1
************************************************************************************/
void f_vd_sendValues(void)
{
unsigned int  value;
unsigned char digit;

f_vd_sendTxd1('s'); /* send start character 's' */

f_vd_sendTxd1('X');
f_vd_sendTxd1(':');
digit = UI_XDIR_VOLTAGE_AD/10000;
f_vd_sendTxd1(0x30+digit);
value = UI_XDIR_VOLTAGE_AD - (digit*10000);
digit = value/1000;
f_vd_sendTxd1(0x30+digit);
value = value - (digit*1000);
digit = value/100;
f_vd_sendTxd1(0x30+digit);
value = value - (digit*100);
digit = value/10;
f_vd_sendTxd1(0x30+digit);
value = value - (digit*10);
digit = value/1;
f_vd_sendTxd1(0x30+digit);

f_vd_sendTxd1('P');
f_vd_sendTxd1(':');
digit = UC_CURRENT_POSITION & 0x03;
f_vd_sendTxd1(0x30+digit);

f_vd_sendTxd1('e'); /* send end character 'e' */
}


#endif

